Changes
=======

1.2.0
-----

* Windows support.
* `-o` option for `text` to print tweets to a file.

1.1.1
-----

* Conda support.

1.1.0
-----

* Python 3 support.

1.0.2
-----
* Producer and consumer process creation and start is fixed.
